# Pong NCurses

The classic game pong with ncurses graphics written in Python 3

# Installation

Make sure you have Python 3.10 or greater installed on you system.

## Linux

Every dependency is part of the Python 3.10+ standard library, so no installations are required. Just run the script like so:

## Windows

Windows hates playing nice, so the installation is a bit more involved.

Install windows-curses
```
pip install windows-curses
```

# Running the game

To run pong, simply run the following from your terminal in the directory that pong.py is located in:
```
python3 pong.py
```

# How to play
- w, s: up, down for player 1
- i, k: up, down for player 2
- q: quit
